@@ -12,6 +12,6 @@ Contains a handful of string related functions.
 from .datetime_functions import generate_all_datetime_regex
 from .iterable_functions import groupby_count
 from .network_functions import download_file
-from .string_functions import random_string
+from .string_functions import *
 from .utility_functions import *
 from .fake_useragent import random_useragent
